@@ -1,6 +1,6 @@
 package Devel::StackTrace::Frame;
 BEGIN {
-  $Devel::StackTrace::Frame::VERSION = '1.25';
+  $Devel::StackTrace::Frame::VERSION = '1.27';
 }
 
 use strict;
@@ -102,6 +102,9 @@ sub as_string {
                 $_ = $self->Devel::StackTrace::_ref_to_string($_)
                     if ref $_;
 
+                local $SIG{__DIE__};
+                local $@;
+
                 eval {
                     if ( $self->{max_arg_length}
                         && length $_ > $self->{max_arg_length} ) {
@@ -149,7 +152,7 @@ Devel::StackTrace::Frame - A single frame in a stack trace
 
 =head1 VERSION
 
-version 1.25
+version 1.27
 
 =head1 DESCRIPTION
 
@@ -195,15 +198,15 @@ that are references are returned as references, not copies.
 
 =head1 AUTHOR
 
-  Dave Rolsky <autarch@urth.org>
+Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2010 by Dave Rolsky.
+This software is Copyright (c) 2011 by Dave Rolsky.
 
 This is free software, licensed under:
 
-  The Artistic License 2.0
+  The Artistic License 2.0 (GPL Compatible)
 
 =cut
 
